Function fce_wit_generator::embed_wit [−][src]
pub fn embed_wit<P>(path: P) -> Result<(), WITGeneratorError> where
P: Into<PathBuf>,
Parse generated by rust-sdk AST types, generate instructions and embed them to Wasm file.
pub fn embed_wit<P>(path: P) -> Result<(), WITGeneratorError> where
P: Into<PathBuf>,
Parse generated by rust-sdk AST types, generate instructions and embed them to Wasm file.